.. !/usr/bin/less
.. =*= coding: utf=8 =*=

.. Copyright (C) 2014 Majormode.  All rights reserved.

.. This software is the confidential and proprietary information of
.. Majormode or one of its subsidiaries.  You shall not disclose this
.. confidential information and shall use it only in accordance with
.. the terms of the license agreement or other applicable agreement
.. you entered into with Majormode.

.. MAJORMODE MAKES NO REPRESENTATIONS OR WARRANTIES ABOUT THE
.. SUITABILITY OF THE SOFTWARE, EITHER EXPRESS OR IMPLIED, INCLUDING
.. BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF MERCHANTABILITY,
.. FITNESS FOR A PARTICULAR PURPOSE, OR NON=INFRINGEMENT.  MAJORMODE
.. SHALL NOT BE LIABLE FOR ANY LOSSES OR DAMAGES SUFFERED BY LICENSEE
.. AS A RESULT OF USING, MODIFYING OR DISTRIBUTING THIS SOFTWARE OR
.. ITS DERIVATIVES.

.. @version $Revision$

============================================
Tracker Device Installation and Registration
============================================

------------
Introduction
------------

USB Installation

Google Play Installation

SIM Card & Data Service Activation
